@@ -1,7 +1,7 @@
-use crate::{ here,wsum,wv,MStats,Med,Stats};
+use crate::{ wsum,MStats,Med,Stats};
 use anyhow::{ensure, Result};
 // use std::ops::Sub;
-pub use indxvec::merge::{sortm,minmax};          
+pub use indxvec::{here,Printing,merge::{sortm,minmax}};          
 
 impl<T> Stats for &[T] 
     where T: Copy+PartialOrd+std::fmt::Display, // +Sub::<Output = T>,
@@ -22,7 +22,7 @@ impl<T> Stats for &[T]
         for &component in self {
            let c = f64::from(component); 
            ensure!(c.is_normal(),
-            "{} reciprocal not allowed for zero components!\n{}\n",here!(),wv(self)); 
+            "{} reciprocal not allowed for zero components!\n{}\n",here!(),self.gr()); 
         }     
         Ok( self.iter().map(|&x| 1.0/(f64::from(x))).collect() )     
     }
@@ -393,15 +393,7 @@ impl<T> Stats for &[T]
         }
         Ok(result)       
     }
-/*
-    /// Fast median only of a &[T] slice by partitioning
-    fn newmedian(self) -> Result<f64> {
-        // define balance of signs closure
-        let balance = |x:f64| self.iter().map(|&s| (f64::from(s)-x).signum()).sum::<f64>(); 
-        let MinMax{min,minindex,max,maxindex} = minmax(self);        
-        Ok(1.)       
-    }
-*/
+
     /// MAD median absolute deviation: data spread estimator that is more stable than variance
     fn mad(self) -> Result<f64> {
         let Med{median,..} = self.median() // ignore quartile fields
