@@ -1,7 +1,7 @@
 use std::iter::FromIterator;
 
-use crate::{Med, MStats, MinMax, MutVecg, MutVecf64, Stats, Vecg, Vecf64, VecVec};
-pub use indxvec::{here,merge::*,Indices};
+use crate::{ Med, MStats, MinMax, MutVecg, MutVecf64, Stats, Vecg, Vecf64, VecVec};
+pub use indxvec::{here,tof64,Printing,merge::*,Indices};
 
 impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
     f64: From<T> {
@@ -22,14 +22,15 @@ impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
     }
 
     /// Joint probability density function of n matched slices of the same length
-    fn jointpdfn(self) -> Vec<f64> {     
+    fn jointpdfn(self) -> Vec<f64> {  
         let d = self[0].len(); // their common dimensionality (length)
         for v in self.iter().skip(1) {
             if v.len() != d { panic!("{} all vectors must be of equal length!",here!()) }; 
         }
         let mut res:Vec<f64> = Vec::with_capacity(d);
         let mut tuples = self.transpose();
-        let df = d as f64; // for turning counts to probabilities
+        let df = tuples.len() as f64; // for turning counts to probabilities
+        println!("{}",df);
         // lexical sort to group together occurrences of identical tuples
         tuples.sort_unstable_by(|a, b| a.partial_cmp(b).unwrap()); 
         let mut count = 1_usize; // running count
@@ -39,14 +40,15 @@ impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
                 res.push((count as f64)/df); // save frequency count as probability
                 lastindex = i; // current index becomes the new one
                 count = 1_usize; // reset counter
-            } else { count += 1; } );        
+            } 
+            else { count += 1; } );        
         res.push((count as f64)/df);  // flush the rest!
         res
     } 
 
     /// Joint entropy of vectors of the same length
     fn jointentropyn(self) -> f64 {
-        let jpdf = self.jointpdfn();
+        let jpdf = self.jointpdfn(); 
         jpdf.iter().map(|&x| -x*(x.ln()) ).sum() 
     }
 
@@ -78,28 +80,14 @@ impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
     }
 
     /// acentroid = simple multidimensional arithmetic mean
-    /// # Example
-    /// ```
-    /// use rstats::{Vecg,VecVec,VecVecg,genvec};
-    /// let pts = genvec(15,15,255,30); 
-    /// let dist = pts.distsum(&pts.acentroid());
-    /// assert_eq!(dist, 4.14556218326653_f64);
-    /// ```
     fn acentroid(self) -> Vec<f64> {
         let mut centre = vec![0_f64; self[0].len()];
         for v in self { centre.mutvadd(v) }
         centre.mutsmultf64(1.0 / (self.len() as f64));
         centre
     }
+
     /// gcentroid = multidimensional geometric mean
-    /// # Example
-    /// ```
-    /// use rstats::{Vecg,VecVec,VecVecg,genvec};
-    /// let pts = genvec(15,15,255,30);
-    /// let centre = pts.gcentroid();
-    /// let dist = pts.distsum(&centre);
-    /// assert_eq!(dist,4.897594485332543_f64);
-    /// ```
     fn gcentroid(self) -> Vec<f64> {
         let nf = self.len() as f64; // number of points
         let d = self[0].len(); // dimensions
@@ -113,14 +101,6 @@ impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
     }
 
     /// hcentroid =  multidimensional harmonic mean
-    /// # Example
-    /// ```
-    /// use rstats::{Vecg,VecVec,VecVecg,genvec};
-    /// let pts = genvec(15,15,255,30);
-    /// let centre = pts.hcentroid();
-    /// let dist = pts.distsum(&centre);
-    /// assert_eq!(dist,5.1272881071877014_f64);
-    /// ```
     fn hcentroid(self) -> Vec<f64> {
         let mut centre = vec![0_f64; self[0].len()]; 
         for v in self { centre.mutvaddf64(&v.vinverse().unwrap()) }
@@ -155,13 +135,6 @@ impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
     /// Outlier is the point with the greatest sum of distances.
     /// In other words, they are the members nearest and furthest from the geometric median. 
     /// Returns struct MinMax{min,minindex,max,maxindex}
-    /// # Example
-    /// ```
-    /// use rstats::{Vecg,VecVec,VecVecg,genvec};
-    /// let pts = genvec(15,15,255,30);
-    /// let mm = pts.medout();
-    /// assert_eq!(mm.min,4.812334638782327_f64);
-    /// ```
     fn medout(self) -> MinMax<f64> {  
         minmax(&self.distsums())
     }
@@ -238,7 +211,7 @@ impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
 
     /// MADn multidimensional median of distances from gm: data spread estimator that is more stable than variances
     fn madn(self, eps: f64) -> f64 {
-        let gm = self.smedian(eps); 
+        let gm = self.gmedian(eps); 
         let eccs:Vec<f64> = self.iter().map(|v| gm.vdist(v)).collect();
         let Med{median,..} = eccs.median().unwrap_or_else(|_| panic!("{},median failed\n",here!()));
         median
@@ -255,16 +228,6 @@ impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
 
     /// Eccentricities of Medoid and Outlier.  
     /// Same as just the third element of a tuple returned by eccinfo
-    /// # Example
-    /// ```
-    /// use rstats::{Vecg,VecVec,genvec};
-    /// pub const EPS:f64 = 1e-7;
-    /// let d = 6_usize;
-    /// let pt = genvec(d,24,7,13); // random test data 5x20
-    /// let mm = pt.emedoid(EPS);
-    /// assert_eq!(mm.minindex,10); // index of e-medoid
-    /// assert_eq!(mm.maxindex,20);  // index of e-outlier
-    /// ```
     fn emedoid(self, eps: f64) -> MinMax<f64> where Vec<f64>:FromIterator<f64> {
     let gm:Vec<f64> = self.gmedian(eps);
     let eccs:Vec<f64> = self.iter().map(|v| gm.vdist(v)).collect();
@@ -273,13 +236,6 @@ impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
 
     /// Initial (first) point for geometric medians.
     /// Same as eccnonmember('origin') but saving the subtractions of zeroes. 
-    /// # Example
-    /// ```
-    /// use rstats::{Vecg,VecVec,VecVecg,genvec};
-    /// let pts = genvec(15,15,255,30); 
-    /// let dist = pts.distsum(&pts.firstpoint());
-    /// assert_eq!(dist,4.132376831171272_f64);
-    /// ```
     fn firstpoint(self) -> Vec<f64> {
         let mut rsum = 0_f64;
         let mut vsum = vec![0_f64; self[0].len()];
@@ -301,19 +257,20 @@ impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
     /// specified by its index `indx` to self. 
     fn nxmember(self, indx: usize) -> Vec<f64> {
         let mut vsum = vec![0_f64; self[0].len()];
-        let p = &self[indx];
+        let p = &tof64(&self[indx]);
         let mut recip = 0_f64;
         for (i,x) in self.iter().enumerate() {
             if i != indx {  // not point p
-                let magsq = x.vdistsq(p);
-                if !magsq.is_normal() { continue } // too close
-                let rec = 1.0_f64/(magsq).sqrt();
-                vsum.mutvaddf64(&x.smultf64(rec)); // add vector
-                recip += rec // add separately the reciprocals 
+                let mag:f64 = x.iter().zip(p).map(|(&xi,&pi)|(f64::from(xi)-pi).powi(2)).sum::<f64>().sqrt(); 
+                if mag.is_normal() { // ignore this point should distance be zero
+                    let rec = 1.0_f64/mag;
+                    vsum.iter_mut().zip(x).for_each(|(vi,xi)| *vi += rec*f64::from(*xi)); 
+                    recip += rec // add separately the reciprocals    
+                }
             }
         };
-        vsum.mutsmultf64(1.0/recip);
-        vsum 
+        vsum.iter_mut().for_each(|vi| *vi /= recip);
+        vsum
     }
  
     /// Next approximate gm computed from a non-member point p
@@ -321,11 +278,12 @@ impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
         let mut vsum = vec![0_f64; self[0].len()];
         let mut recip = 0_f64;
         for x in self { 
-            let magsq:f64 = x.iter().zip(p).map(|(&xi,&pi)|(f64::from(xi)-pi).powi(2)).sum(); 
-            if !magsq.is_normal() { continue } // zero distance, safe to ignore
-            let rec = 1.0_f64/(magsq).sqrt();
-            vsum.iter_mut().zip(x).for_each(|(vi,xi)| *vi += rec*f64::from(*xi)); 
-            recip += rec // add separately the reciprocals    
+            let mag:f64 = x.iter().zip(p).map(|(&xi,&pi)|(f64::from(xi)-pi).powi(2)).sum::<f64>().sqrt(); 
+            if mag.is_normal() { // ignore this point should distance be zero
+                let rec = 1.0_f64/mag;
+                vsum.iter_mut().zip(x).for_each(|(vi,xi)| *vi += rec*f64::from(*xi)); 
+                recip += rec // add separately the reciprocals    
+            }
         }
         vsum.iter_mut().for_each(|vi| *vi /= recip);
         vsum
@@ -340,53 +298,24 @@ impl<T> VecVec<T> for &[Vec<T>] where T: Copy+PartialOrd+std::fmt::Display,
     /// There will eventually be a multithreaded version.
     fn gmedian(self, eps: f64) -> Vec<f64> {
         let eps2 = eps.powi(2);
-        let mut point = self.acentroid(); // start iterating from the Centre
+        let mut p = self.acentroid(); // start iterating from the Centre
         loop { // vector iteration till accuracy eps2 is reached
-            let nextp = self.nxnonmember(&point);          
-            if nextp.vdistsqf64(&point) < eps2 { return nextp }; // termination 
-            point = nextp;
-        } 
+            let nextp = self.nxnonmember(&p);          
+            if nextp.iter().zip(p).map(|(&xi,pi)|(xi-pi).powi(2)).sum::<f64>() < eps2 { return nextp }; // termination 
+            p = nextp;
+        }; 
     }
 
-    /// Secant recovery from divergence
-    /// for finding the geometric median.
-    /// Initialised with acentroid.
-    fn smedian(self, eps: f64) -> Vec<f64> {  
+    /// Same a gmedian but returns also the number of iterations
+    fn igmedian(self, eps: f64) -> ( Vec<f64>, usize ) {  
         let eps2 = eps.powi(2);
-        let mut p1 = self.acentroid();
-        let mut mag1:f64 = p1.iter().map(|&c| c.powi(2)).sum();
+        let mut p = self.acentroid(); 
+        let mut iterations = 1_usize;
         loop {  
-            let p2 = self.nxnonmember(&p1);                                       
-            let e:Vec<f64> = p2.iter().zip(&p1).map(|(&p2i,&p1i)| p2i-p1i).collect(); // new vector error, or eccentricity  
-            let mag2:f64 = e.iter().map(|&c| c.powi(2)).sum();
-            if mag2 < eps2 { return p2 }; // termination
-            let secant = mag1/(mag1-mag2);
-            p1.iter_mut().zip(e).for_each(|(pi,ei)| *pi += ei*secant); 
-            mag1 = mag2;
-        };     
-    }
-
-    /// Same a smedian but returns also the number of iterations
-    /// # Example
-    /// ```
-    /// use rstats::{Vecg,VecVec,VecVecg,genvec};
-    /// let pts = genvec(25,25,255,30); 
-    /// let (gm,iterations) = pts.ismedian(1e-10);  
-    /// assert_eq!(iterations,11);
-    /// ```
-    fn ismedian(self, eps: f64) -> ( Vec<f64>, usize ) {  
-        let eps2 = eps.powi(2);
-        let mut p1 = self.acentroid();
-        let mut mag1:f64 = p1.iter().map(|c| c.powi(2)).sum();
-        let mut iterations = 2_usize;
-        loop {  
-            let p2 = self.nxnonmember(&p1);                                       
-            let e = p2.vsubf64(&p1); // new vector error, or eccentricity   
-            let mag2:f64 = e.iter().map(|c| c.powi(2)).sum();
-            if mag2 < eps2 { return (p2,iterations) }; // termination
-            p1.mutvaddf64(&e.smultf64(mag1/(mag1-mag2))); 
-            mag1 = mag2;
+            let nextp = self.nxnonmember(&p);
+            if nextp.vdistsqf64(&p) < eps2 { return (nextp,iterations) }; // termination
             iterations +=1;
+            p = nextp;
         };     
     }
 }
